@@ -5,7 +5,7 @@
 @Date  : 2021/12/4 12:17 上午
 @Desc  : 人群包提取
 '''
-
+import os
 import pandas
 import time
 import pyspark.sql.functions as F
@@ -19,12 +19,11 @@ from jklwcs.udff import get_package_name, get_category
 from jklwcs.func import tran_business_hours,get_logger
 
 
-
 class SelectUuid(object):
     """ 基础数据包查询类"""
 
-    def __int__(self):
-        pass
+    def __int__(self,pyspark_python):
+        os.environ['PYSPARK_PYTHON'] = pyspark_python
 
     def select_uuid_from_arrvied_data(
         self,
